shishi-commit
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

CVS shishi/lib


From: shishi-commit
Subject: CVS shishi/lib
Date: Tue, 09 Nov 2004 19:46:26 +0100

Update of /home/cvs/shishi/lib
In directory dopio:/tmp/cvs-serv4578

Modified Files:
        shishi.h.in resolv.c krberror.c 
Log Message:
Doc fix.


--- /home/cvs/shishi/lib/shishi.h.in    2004/10/14 20:28:13     1.256
+++ /home/cvs/shishi/lib/shishi.h.in    2004/11/09 18:46:26     1.257
@@ -1290,7 +1290,7 @@
                                       const char *crealm);
 extern int shishi_krberror_client (Shishi * handle,
                                   Shishi_asn1 krberror,
-                                  char **cname, size_t *cnamelen);
+                                  char **client, size_t * clientlen);
 extern int shishi_krberror_set_cname (Shishi * handle,
                                      Shishi_asn1 krberror,
                                      Shishi_name_type name_type,
--- /home/cvs/shishi/lib/krberror.c     2004/10/15 11:05:57     1.40
+++ /home/cvs/shishi/lib/krberror.c     2004/11/09 18:46:26     1.41
@@ -615,7 +615,7 @@
  * @krberror: krberror as allocated by shishi_krberror().
  * @server: pointer to newly allocated zero terminated string containing
  *   server name.  May be %NULL (to only populate @serverlen).
- * @snamelen: pointer to length of @server on output, excluding terminating
+ * @serverlen: pointer to length of @server on output, excluding terminating
  *   zero.  May be %NULL (to only populate @server).
  *
  * Return server principal name in KRB-ERROR.





reply via email to

[Prev in Thread] Current Thread [Next in Thread]
--- /home/cvs/shishi/lib/resolv.c       2004/10/15 11:05:57     1.12
+++ /home/cvs/shishi/lib/resolv.c       2004/11/09 18:46:26     1.13
@@ -270,20 +270,20 @@
 
 /**
  * shishi_resolv_free:
  * @dns: list of DNS RR as returned by shishi_resolv().
  *
  * Deallocate list of DNS RR as returned by shishi_resolv().
  **/
 void
-shishi_resolv_free (Shishi_dns dns)
+shishi_resolv_free (Shishi_dns rrs)
 {
   Shishi_dns next;
 
-  while (dns != NULL)
+  while (rrs != NULL)
     {
-      next = dns->next;
-      free (dns->rr);
-      free (dns);
-      dns = next;
+      next = rrs->next;
+      free (rrs->rr);
+      free (rrs);
+      rrs = next;
     }
 }
@@ -270,20 +270,20 @@
 /**
  * shishi_resolv_free:
- * @dns: list of DNS RR as returned by shishi_resolv().
+ * @rrs: list of DNS RR as returned by shishi_resolv().
  *
  * Deallocate list of DNS RR as returned by shishi_resolv().